@@ -1,20 +1,23 @@
 import time
+
 from eth_abi import encode
 from eth_account.messages import encode_structured_data
 from eth_utils import keccak, to_hex
 
-from hyperliquid.utils.types import TypedDict, Literal, Union, Any, Tuple
+from hyperliquid.utils.types import Any, Literal, Tuple, TypedDict, Union
 
 ZERO_ADDRESS = "0x0000000000000000000000000000000000000000"
 
 Tif = Union[Literal["Alo"], Literal["Ioc"], Literal["Gtc"]]
 Tpsl = Union[Literal["tp"], Literal["sl"]]
 LimitOrderType = TypedDict("LimitOrderType", {"tif": Tif})
-TriggerOrderType = TypedDict("TriggerOrderType", {"triggerPx": int, "isMarket": bool, "tpsl": Tpsl})
+TriggerOrderType = TypedDict("TriggerOrderType", {"triggerPx": float, "isMarket": bool, "tpsl": Tpsl})
+TriggerOrderTypeWire = TypedDict("TriggerOrderTypeWire", {"triggerPx": str, "isMarket": bool, "tpsl": Tpsl})
 OrderType = TypedDict("OrderType", {"limit": LimitOrderType, "trigger": TriggerOrderType}, total=False)
+OrderTypeWire = TypedDict("OrderTypeWire", {"limit": LimitOrderType, "trigger": TriggerOrderTypeWire}, total=False)
 
 
-def order_type_to_tuple(order_type: OrderType) -> Tuple[int, int]:
+def order_type_to_tuple(order_type: OrderType) -> Tuple[int, float]:
     if "limit" in order_type:
         tif = order_type["limit"]["tif"]
         if tif == "Gtc":
@@ -68,10 +71,25 @@ def order_spec_preprocessing(order_spec: OrderSpec) -> Any:
 
 
 OrderWire = TypedDict(
-    "OrderWire", {"asset": int, "isBuy": bool, "limitPx": str, "sz": str, "reduceOnly": bool, "orderType": OrderType}
+    "OrderWire",
+    {"asset": int, "isBuy": bool, "limitPx": str, "sz": str, "reduceOnly": bool, "orderType": OrderTypeWire},
 )
 
 
+def order_type_to_wire(order_type: OrderType) -> OrderTypeWire:
+    if "limit" in order_type:
+        return {"limit": order_type["limit"]}
+    elif "trigger" in order_type:
+        return {
+            "trigger": {
+                "triggerPx": float_to_wire(order_type["trigger"]["triggerPx"]),
+                "tpsl": order_type["trigger"]["tpsl"],
+                "isMarket": order_type["trigger"]["isMarket"],
+            }
+        }
+    raise ValueError("Invalid order type", order_type)
+
+
 def order_spec_to_order_wire(order_spec: OrderSpec) -> OrderWire:
     order = order_spec["order"]
     return {
@@ -80,7 +98,7 @@ def order_spec_to_order_wire(order_spec: OrderSpec) -> OrderWire:
         "limitPx": float_to_wire(order["limitPx"]),
         "sz": float_to_wire(order["sz"]),
         "reduceOnly": order["reduceOnly"],
-        "orderType": order_spec["orderType"],
+        "orderType": order_type_to_wire(order_spec["orderType"]),
     }
 
 
@@ -137,9 +155,17 @@ def float_to_wire(x: float) -> str:
 
 
 def float_to_int_for_hashing(x: float) -> int:
-    with_decimals = x * 10**8
+    return float_to_int(x, 8)
+
+
+def float_to_usd_int(x: float) -> int:
+    return float_to_int(x, 6)
+
+
+def float_to_int(x: float, power: int) -> int:
+    with_decimals = x * 10**power
     if abs(round(with_decimals) - with_decimals) >= 1e-4:
-        raise ValueError("float_to_int_for_hashing causes rounding", x)
+        raise ValueError("float_to_int causes rounding", x)
     return round(with_decimals)
 
 
